import { StatusTypes } from '@clr/core/internal';
import { LitElement } from 'lit-element';
/**
 * Badges provide a method to highlight a count of an element either next to it
 * or inside the element itself.
 *
 * ```typescript
 * import '@clr/core/badge/register.js';
 * ```
 *
 * ```html
 * <cds-badge status="info">2</cds-badge>
 * ```
 * @beta
 * @element cds-badge
 * @slot - Content slot for inside the badge
 * @cssprop --background
 * @cssprop --border-color
 * @cssprop --border-radius
 * @cssprop --border-width
 * @cssprop --color
 * @cssprop --font-size
 * @cssprop --font-weight
 * @cssprop --padding
 * @cssprop --size
 */
export declare class CdsBadge extends LitElement {
    /**
     * Sets the color of the badge
     */
    color: 'default' | 'gray' | 'purple' | 'blue' | 'orange' | 'light-blue';
    /**
     * @type {default | info | success | warning | danger}
     * Sets the color of the badge
     */
    status: StatusTypes;
    render(): import("lit-element").TemplateResult;
    static get styles(): import("lit-element").CSSResult[];
}
