export declare type KeyCodeValues = Map<'code' | 'ie-code', string>;
export declare type KeyCodeHashmap = Map<string, KeyCodeValues>;
/**
 * KeyCodes is a static class that gives users the ability to lookup and even store
 * keycodes for their applications.
 *
 * @privateRemarks
 *
 * The key codes dictionary/hashmap is private to this module. There is no way to access it directly
 * outside of the module.
 *
 */
export declare class KeyCodeService {
    /**
     * keycodes() returns a clone of the key codes dictionary/hashmap, not the actual registry.
     * Performing actions on the return value of the keycodes getter will not be reflected in the
     * actual keycodes dictionary!
     */
    static get keycodes(): KeyCodeHashmap;
    static add(keycode: string, code: string, legacyCode?: string): void;
    static has(keycode: string): boolean;
    static getCode(keycode: string): string;
    static getIeCode(keycode: string): string;
}
export declare function getKeycodeFromRegistry(codeToLookup: string, whichCodeType?: 'code' | 'ie-code', registry?: KeyCodeHashmap): string;
