/*
 * Copyright (c) 2016-2020 VMware, Inc. All Rights Reserved.
 * This software is released under MIT license.
 * The full license information can be found in LICENSE in the root directory of this project.
 */
import { __decorate } from "tslib";
import { internalProperty, html } from 'lit-element';
import { CommonStringsService } from '@clr/core/internal';
import { CdsControl } from '@clr/core/forms';
import { inputStyles } from '@clr/core/input';
import { ClarityIcons } from '@clr/core/icon/icon.service.js';
import { eyeIcon } from '@clr/core/icon/shapes/eye.js';
import { eyeHideIcon } from '@clr/core/icon/shapes/eye-hide.js';
/**
 * Password
 *
 * ```typescript
 * import '@clr/core/password/register.js';
 * ```
 *
 * ```html
 * <cds-password>
 *   <label>Password</label>
 *   <input type="password" />
 *   <cds-control-message>message text</cds-control-message>
 * </cds-password>
 * ```
 *
 * @element cds-password
 * @slot - For projecting password input and label
 * @cssprop --background
 * @cssprop --background-size
 * @cssprop --border
 * @cssprop --border-bottom
 * @cssprop --outline
 * @cssprop --padding
 * @cssprop --font-size
 * @cssprop --color
 * @cssprop --line-height
 * @cssprop --transition
 */
export class CdsPassword extends CdsControl {
    constructor() {
        super();
        this.showPassword = false;
        ClarityIcons.addIcons(eyeIcon, eyeHideIcon);
    }
    get ariaLabel() {
        return this.showPassword ? CommonStringsService.keys.hide : CommonStringsService.keys.show;
    }
    get suffixDefaultTemplate() {
        return html `
      <cds-control-action @click=${() => this.togglePasswordVisibility()} aria-label="${this.ariaLabel}">
        <cds-icon shape="${this.showPassword ? 'eye-hide' : 'eye'}"></cds-icon>
      </cds-control-action>
    `;
    }
    static get styles() {
        return [...super.styles, inputStyles];
    }
    togglePasswordVisibility() {
        this.showPassword = !this.showPassword;
        this.inputControl.type = this.showPassword ? 'text' : 'password';
    }
}
__decorate([
    internalProperty()
], CdsPassword.prototype, "showPassword", void 0);
//# sourceMappingURL=password.element.js.map