/*
 * Copyright (c) 2016-2020 VMware, Inc. All Rights Reserved.
 * This software is released under MIT license.
 * The full license information can be found in LICENSE in the root directory of this project.
 */
import { __decorate } from "tslib";
import { html } from 'lit-element';
import { globalStyle } from '@clr/core/internal';
import { CdsControl } from '@clr/core/forms';
import { inputStyles } from '@clr/core/input';
import { ClarityIcons } from '@clr/core/icon/icon.service.js';
import { clockIcon } from '@clr/core/icon/shapes/clock.js';
import { styles as globalStyles } from './time.global.css.js';
/**
 * Time Input
 *
 * ```typescript
 * import '@clr/core/time/register.js';
 * ```
 *
 * ```html
 * <cds-time>
 *   <label>time</label>
 *   <input type="time" />
 *   <cds-control-message>message text</cds-control-message>
 * </cds-time>
 * ```
 *
 * @element cds-time
 * @slot - For projecting time input and label
 * @cssprop --background
 * @cssprop --background-size
 * @cssprop --border
 * @cssprop --border-bottom
 * @cssprop --outline
 * @cssprop --padding
 * @cssprop --font-size
 * @cssprop --color
 * @cssprop --line-height
 * @cssprop --transition
 */
export class CdsTime extends CdsControl {
    constructor() {
        super();
        this.globalStyles = globalStyles;
        ClarityIcons.addIcons(clockIcon);
    }
    get suffixDefaultTemplate() {
        return html `<cds-control-action readonly><cds-icon shape="clock" size="18"></cds-icon></cds-control-action>`;
    }
    static get styles() {
        return [...super.styles, inputStyles];
    }
}
__decorate([
    globalStyle()
], CdsTime.prototype, "globalStyles", void 0);
//# sourceMappingURL=time.element.js.map